@@ -19,6 +19,6 @@
 
 LIBDIR = r'/usr/local/lib'
 DATADIR = r'/usr/local/share'
-BUILDDIR = r'/usr/obj/ports/gst-devtools-1.26.5/build-powerpc64'
-SRCDIR = r'/usr/obj/ports/gst-devtools-1.26.5/gst-devtools-1.26.5'
+BUILDDIR = r'/usr/obj/ports/gst-devtools-1.26.6/build-sparc64'
+SRCDIR = r'/usr/obj/ports/gst-devtools-1.26.6/gst-devtools-1.26.6'
 GST_VALIDATE_TESTSUITE_VERSION = '1.26'
